using BinaryProvider

# Parse some basic command-line arguments
const verbose = "--verbose" in ARGS
const prefix = Prefix(get([a for a in ARGS if a != "--verbose"], 1, joinpath(@__DIR__, "usr")))
products = [
    LibraryProduct(prefix, ["libsmumps"], :libsmumps),
    LibraryProduct(prefix, ["libdmumps"], :libdmumps),
    LibraryProduct(prefix, ["libcmumps"], :libcmumps),
    LibraryProduct(prefix, ["libzmumps"], :libzmumps),
]

# Download binaries from hosted location
bin_prefix = "https://github.com/JuliaBinaryWrappers/MUMPS_seq_jll.jl/releases/download/MUMPS_seq-v5.2.1+3"

# Listing of files generated by BinaryBuilder:
download_info = Dict(
    Linux(:aarch64, libc=:glibc, compiler_abi=CompilerABI(:gcc4)) => ("$bin_prefix/MUMPS_seq.v5.2.1.aarch64-linux-gnu-libgfortran3.tar.gz", "21e8c3a71082e2750b81dfa3363a36405f91c9ff646c696d74b927908e07e4d3"),
    Linux(:aarch64, libc=:glibc, compiler_abi=CompilerABI(:gcc7)) => ("$bin_prefix/MUMPS_seq.v5.2.1.aarch64-linux-gnu-libgfortran4.tar.gz", "c87adc2d7ea167e931385c0638fc4cb7ff94a6f53690622a0fd1ed82f86e11fd"),
    Linux(:aarch64, libc=:glibc, compiler_abi=CompilerABI(:gcc8)) => ("$bin_prefix/MUMPS_seq.v5.2.1.aarch64-linux-gnu-libgfortran5.tar.gz", "f5b60be4827dd899c870c6f9ad9a3e3efe7408ac31aa59694a393e597c05e7a6"),
    Linux(:aarch64, libc=:musl, compiler_abi=CompilerABI(:gcc4)) => ("$bin_prefix/MUMPS_seq.v5.2.1.aarch64-linux-musl-libgfortran3.tar.gz", "23f28bf4f558187e7f4d546843e51af4ff1c0432e4a9373a5cabda35358a6f47"),
    Linux(:aarch64, libc=:musl, compiler_abi=CompilerABI(:gcc7)) => ("$bin_prefix/MUMPS_seq.v5.2.1.aarch64-linux-musl-libgfortran4.tar.gz", "509d4e43f44300e19d4d3eb759f21926a83ec185012be2f22f515bf51418d175"),
    Linux(:aarch64, libc=:musl, compiler_abi=CompilerABI(:gcc8)) => ("$bin_prefix/MUMPS_seq.v5.2.1.aarch64-linux-musl-libgfortran5.tar.gz", "30c246d97a5923b040c01d6ec18f105e6c348ec68ebb308dcd34e8fae9af4598"),
    Linux(:armv7l, libc=:glibc, call_abi=:eabihf, compiler_abi=CompilerABI(:gcc4)) => ("$bin_prefix/MUMPS_seq.v5.2.1.armv7l-linux-gnueabihf-libgfortran3.tar.gz", "f851b4dc1ff2e79c72a3e52986f129d09ac2c1db5524b2dbca19db9adea6d298"),
    Linux(:armv7l, libc=:glibc, call_abi=:eabihf, compiler_abi=CompilerABI(:gcc7)) => ("$bin_prefix/MUMPS_seq.v5.2.1.armv7l-linux-gnueabihf-libgfortran4.tar.gz", "72888a7169a893054da3907eb7cddf1af3211dd25bd3e7ef1a272ee1caaaeaa6"),
    Linux(:armv7l, libc=:glibc, call_abi=:eabihf, compiler_abi=CompilerABI(:gcc8)) => ("$bin_prefix/MUMPS_seq.v5.2.1.armv7l-linux-gnueabihf-libgfortran5.tar.gz", "db9189233720bb1c4c3de29ee5c6b2f4a742c55f842340a71da47e6edf9bcdc7"),
    Linux(:armv7l, libc=:musl, call_abi=:eabihf, compiler_abi=CompilerABI(:gcc4)) => ("$bin_prefix/MUMPS_seq.v5.2.1.armv7l-linux-musleabihf-libgfortran3.tar.gz", "f34f2e748a9cfd419a741519352103d57f95eca2d37d1b9689ec43a8baa833bc"),
    Linux(:armv7l, libc=:musl, call_abi=:eabihf, compiler_abi=CompilerABI(:gcc7)) => ("$bin_prefix/MUMPS_seq.v5.2.1.armv7l-linux-musleabihf-libgfortran4.tar.gz", "a7e45363572d991b048cc710cf9d4baab36837e79bde31402b55279a6a61c669"),
    Linux(:armv7l, libc=:musl, call_abi=:eabihf, compiler_abi=CompilerABI(:gcc8)) => ("$bin_prefix/MUMPS_seq.v5.2.1.armv7l-linux-musleabihf-libgfortran5.tar.gz", "20c02cd59d1eac8b7d732472cdd4401e422d95a9ee863686967523754d2bafe5"),
    Linux(:i686, libc=:glibc, compiler_abi=CompilerABI(:gcc4)) => ("$bin_prefix/MUMPS_seq.v5.2.1.i686-linux-gnu-libgfortran3.tar.gz", "debb72c43efd3efce5976fb30ba57e2dad8a5ae6261c2f37e5e54e1cd58e2382"),
    Linux(:i686, libc=:glibc, compiler_abi=CompilerABI(:gcc7)) => ("$bin_prefix/MUMPS_seq.v5.2.1.i686-linux-gnu-libgfortran4.tar.gz", "2240454e3f309196732b347bb166fdc52550b9f0c567e68876f88a0df1e9db6e"),
    Linux(:i686, libc=:glibc, compiler_abi=CompilerABI(:gcc8)) => ("$bin_prefix/MUMPS_seq.v5.2.1.i686-linux-gnu-libgfortran5.tar.gz", "9ed2d5cbefc4e181f9a37be079afabbff37da82d8e336b78f02aeaa6edf13975"),
    Linux(:i686, libc=:musl, compiler_abi=CompilerABI(:gcc4)) => ("$bin_prefix/MUMPS_seq.v5.2.1.i686-linux-musl-libgfortran3.tar.gz", "183159546b60021168d7be95d2e031928553ff4e8342a282d2044a0144e05078"),
    Linux(:i686, libc=:musl, compiler_abi=CompilerABI(:gcc7)) => ("$bin_prefix/MUMPS_seq.v5.2.1.i686-linux-musl-libgfortran4.tar.gz", "e79de503dcdaf40f7c6ad65de38a9fc94324380cd204d36da63a247e904838e3"),
    Linux(:i686, libc=:musl, compiler_abi=CompilerABI(:gcc8)) => ("$bin_prefix/MUMPS_seq.v5.2.1.i686-linux-musl-libgfortran5.tar.gz", "bb2ee2cf2401a67e233978482272f68eeb934a6ace591816576bf8e0ca9bed0c"),
    Windows(:i686, compiler_abi=CompilerABI(:gcc4)) => ("$bin_prefix/MUMPS_seq.v5.2.1.i686-w64-mingw32-libgfortran3.tar.gz", "c09a2a9a8db56f7885190864e8dfe60da0f01524090369d6ea26bbf590b650e6"),
    Windows(:i686, compiler_abi=CompilerABI(:gcc7)) => ("$bin_prefix/MUMPS_seq.v5.2.1.i686-w64-mingw32-libgfortran4.tar.gz", "4a8aced6f8575bbcf452a5ad437206c9b0015f664771fd56bf5b91f532fb1a24"),
    Windows(:i686, compiler_abi=CompilerABI(:gcc8)) => ("$bin_prefix/MUMPS_seq.v5.2.1.i686-w64-mingw32-libgfortran5.tar.gz", "b4c50734f683c709839a44232c25be721151a4d6a6c9552bba696875d9cda225"),
    Linux(:powerpc64le, libc=:glibc, compiler_abi=CompilerABI(:gcc4)) => ("$bin_prefix/MUMPS_seq.v5.2.1.powerpc64le-linux-gnu-libgfortran3.tar.gz", "83b4489c983700f059f41a954dc5a6d32c5cea8287ce54d4137dca8e1030d1aa"),
    Linux(:powerpc64le, libc=:glibc, compiler_abi=CompilerABI(:gcc7)) => ("$bin_prefix/MUMPS_seq.v5.2.1.powerpc64le-linux-gnu-libgfortran4.tar.gz", "b1ce89eebe255974457c149e0496264aff895e2219dd163d0bf590c0b8013657"),
    Linux(:powerpc64le, libc=:glibc, compiler_abi=CompilerABI(:gcc8)) => ("$bin_prefix/MUMPS_seq.v5.2.1.powerpc64le-linux-gnu-libgfortran5.tar.gz", "c9d2d88945f169e0045a099e7635f091b1b4ebc6e8e11088b9adcf1b2f835723"),
    MacOS(:x86_64, compiler_abi=CompilerABI(:gcc4)) => ("$bin_prefix/MUMPS_seq.v5.2.1.x86_64-apple-darwin14-libgfortran3.tar.gz", "7932027ee827b39aa8575d40c882d1fac6161e682b10ff54c63f4c48e9af66d7"),
    MacOS(:x86_64, compiler_abi=CompilerABI(:gcc7)) => ("$bin_prefix/MUMPS_seq.v5.2.1.x86_64-apple-darwin14-libgfortran4.tar.gz", "3e2c348c560fcab95c5900319f13ff251eefb58a5e1d2bf434409fea4aadf5b4"),
    MacOS(:x86_64, compiler_abi=CompilerABI(:gcc8)) => ("$bin_prefix/MUMPS_seq.v5.2.1.x86_64-apple-darwin14-libgfortran5.tar.gz", "b5d0cfd50b9da8fa537b4d314fbed0ea2be799e463979ba692fe05d7a31c3686"),
    Linux(:x86_64, libc=:glibc, compiler_abi=CompilerABI(:gcc4)) => ("$bin_prefix/MUMPS_seq.v5.2.1.x86_64-linux-gnu-libgfortran3.tar.gz", "cddd0fe9c2f9c0da1409d5169c18f4c22a4227a61dc674ecdc88b031d6a47024"),
    Linux(:x86_64, libc=:glibc, compiler_abi=CompilerABI(:gcc7)) => ("$bin_prefix/MUMPS_seq.v5.2.1.x86_64-linux-gnu-libgfortran4.tar.gz", "ef11f0cab1dc03ed1dfaeeee1e58d454067bc45902cfd23d317d3caf74b7ea57"),
    Linux(:x86_64, libc=:glibc, compiler_abi=CompilerABI(:gcc8)) => ("$bin_prefix/MUMPS_seq.v5.2.1.x86_64-linux-gnu-libgfortran5.tar.gz", "8f335755356604195f3f5ba2c487a30675a2cfa5f0d862c5a50871d1e4729e4b"),
    Linux(:x86_64, libc=:musl, compiler_abi=CompilerABI(:gcc4)) => ("$bin_prefix/MUMPS_seq.v5.2.1.x86_64-linux-musl-libgfortran3.tar.gz", "c8c54fea6c8d995a6c2b1b81f497d6197d57c60012ecda7d8a43c48ec7160d67"),
    Linux(:x86_64, libc=:musl, compiler_abi=CompilerABI(:gcc7)) => ("$bin_prefix/MUMPS_seq.v5.2.1.x86_64-linux-musl-libgfortran4.tar.gz", "f994b151b691fde3f52c2f5adedd1bd667df3bc275a782a8724ebba69a5eca03"),
    Linux(:x86_64, libc=:musl, compiler_abi=CompilerABI(:gcc8)) => ("$bin_prefix/MUMPS_seq.v5.2.1.x86_64-linux-musl-libgfortran5.tar.gz", "0fdfe21ae60a7de9a2db872bab46cc1006d7124cf9d2bede47ff033db421186e"),
    FreeBSD(:x86_64, compiler_abi=CompilerABI(:gcc4)) => ("$bin_prefix/MUMPS_seq.v5.2.1.x86_64-unknown-freebsd11.1-libgfortran3.tar.gz", "5524142eb24789c5212d44e9369bc38e7e2427fbe42b0d7d826121d529983c8b"),
    FreeBSD(:x86_64, compiler_abi=CompilerABI(:gcc7)) => ("$bin_prefix/MUMPS_seq.v5.2.1.x86_64-unknown-freebsd11.1-libgfortran4.tar.gz", "2b4e263aebe63b1a0abaece449ef3a4514b99e1665356cc13153482d40731ebb"),
    FreeBSD(:x86_64, compiler_abi=CompilerABI(:gcc8)) => ("$bin_prefix/MUMPS_seq.v5.2.1.x86_64-unknown-freebsd11.1-libgfortran5.tar.gz", "7c95682c64333285cf1d5fa2925bd0b21c917f02f307116ac3985e680a28c57d"),
    Windows(:x86_64, compiler_abi=CompilerABI(:gcc4)) => ("$bin_prefix/MUMPS_seq.v5.2.1.x86_64-w64-mingw32-libgfortran3.tar.gz", "554abab4e26cddb33ce04de2171c04c04f48b866910ed87be2bea4a4c8dc5918"),
    Windows(:x86_64, compiler_abi=CompilerABI(:gcc7)) => ("$bin_prefix/MUMPS_seq.v5.2.1.x86_64-w64-mingw32-libgfortran4.tar.gz", "af87cc4dd2c653b52d72a86384fc51108f6cf506daddbf7b5fa9e815ab5d409c"),
    Windows(:x86_64, compiler_abi=CompilerABI(:gcc8)) => ("$bin_prefix/MUMPS_seq.v5.2.1.x86_64-w64-mingw32-libgfortran5.tar.gz", "e94a8a2efc1c4a8b904bee11627f691c5a3663eff94a6c769e639079091d361b"),
)

# Install unsatisfied or updated dependencies:
# We added `, isolate=true` as otherwise, it would segfault when closing `OpenBLAS32`,
# probably because it is conflicting with Julia openblas.
unsatisfied = any(!satisfied(p; verbose=verbose, isolate=true) for p in products)
dl_info = choose_download(download_info, platform_key_abi())
if dl_info === nothing && unsatisfied
    # If we don't have a compatible .tar.gz to download, complain.
    # Alternatively, you could attempt to install from a separate provider,
    # build from source or something even more ambitious here.
    error("Your platform (\"$(Sys.MACHINE)\", parsed as \"$(triplet(platform_key_abi()))\") is not supported by this package!")
end

# If we have a download, and we are unsatisfied (or the version we're
# trying to install is not itself installed) then load it up!
if unsatisfied || !isinstalled(dl_info...; prefix=prefix)
    # Download and install binaries
    install(dl_info...; prefix=prefix, force=true, verbose=verbose)
end
